pygeai.tests.snippets.evaluation.result package
===============================================

Submodules
----------

pygeai.tests.snippets.evaluation.result.complete\_workflow\_example module
--------------------------------------------------------------------------

.. automodule:: pygeai.tests.snippets.evaluation.result.complete_workflow_example
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.evaluation.result.get\_evaluation\_result module
----------------------------------------------------------------------

.. automodule:: pygeai.tests.snippets.evaluation.result.get_evaluation_result
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.evaluation.result.list\_evaluation\_results module
------------------------------------------------------------------------

.. automodule:: pygeai.tests.snippets.evaluation.result.list_evaluation_results
   :members:
   :show-inheritance:
   :undoc-members:

Module contents
---------------

.. automodule:: pygeai.tests.snippets.evaluation.result
   :members:
   :show-inheritance:
   :undoc-members:
